@@ -18,6 +18,7 @@ __date__ = "Jan 26, 2013"
 import unittest
 import datetime
 import os
+import json
 
 
 @explicit_serialize
@@ -47,7 +48,7 @@ class SerializationTest(unittest.TestCase):
         self.obj_2 = TestSerializer({"p1": 1234, "p2": 5.0, "p3": "Hi!", 'p4': datetime.datetime.utcnow()}, test_date)
 
         # A unicode test serialized object
-        unicode_str = unicode('\xc3\xa4\xc3\xb6\xc3\xbc', 'utf-8')
+        unicode_str = u'\xe4\xf6\xfc'
         self.obj_3 = ExportTestSerializer({"p1": unicode_str, "p2": "abc"})
         self.obj_3.to_file("test.json")
         self.obj_3.to_file("test.yaml")
@@ -102,9 +103,11 @@ class SerializationTest(unittest.TestCase):
                          'Unicode YAML format export / import fails!')
 
     def test_unicode_json_file(self):
-        with open(os.path.join(self.module_dir, "test_reference.json")) as f:
-            with open("test.json") as f2:
-                self.assertEqual(f.read(), f2.read(), 'Unicode JSON file export fails')
+        with open(os.path.join(self.module_dir, "test_reference.json")) as f,\
+                open("test.json") as f2:
+            obj1 = json.load(f)
+            obj2 = json.load(f2)
+            self.assertEqual(obj1, obj2, 'Unicode JSON file export fails')
 
         self.assertEqual(self.obj_3.from_file("test.json"), self.obj_3, 'Unicode JSON file import fails!')
 
@@ -129,4 +132,4 @@ class ExplicitSerializationTest(unittest.TestCase):
         self.assertEqual(load_object(self.s_dict), self.s_obj)
 
 if __name__ == "__main__":
-    unittest.main()
\ No newline at end of file
+    unittest.main()
